<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Michigan";
    var qsoPartyUrl = "http://www.miqp.org/";
    var overlayUrl = "http://www.no5w.com/OverlayMichiganRev4.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Alcona", "alco");
  countySelection.options[1] = new Option("Alger", "alge");
  countySelection.options[2] = new Option("Allegan", "alle");
  countySelection.options[3] = new Option("Alpena", "alpe");
  countySelection.options[4] = new Option("Antrim", "antr");
  countySelection.options[5] = new Option("Arenac", "aren");
  countySelection.options[6] = new Option("Baraga", "bara");
  countySelection.options[7] = new Option("Barry", "barr");
  countySelection.options[8] = new Option("Bay", "bay");
  countySelection.options[9] = new Option("Benzie", "benz");
  countySelection.options[10] = new Option("Berrien", "berr");
  countySelection.options[11] = new Option("Branch", "bran");
  countySelection.options[12] = new Option("Calhoun", "calh");
  countySelection.options[13] = new Option("Cass", "cass");
  countySelection.options[14] = new Option("Charlevoix", "char");
  countySelection.options[15] = new Option("Cheboygan", "cheb");
  countySelection.options[16] = new Option("Chippewa", "chip");
  countySelection.options[17] = new Option("Clare", "clar");
  countySelection.options[18] = new Option("Clinton", "clin");
  countySelection.options[19] = new Option("Crawford", "craw");
  countySelection.options[20] = new Option("Delta", "delt");
  countySelection.options[21] = new Option("Dickinson", "dick");
  countySelection.options[22] = new Option("Eaton", "eato");
  countySelection.options[23] = new Option("Emmet", "emme");
  countySelection.options[24] = new Option("Genesee", "gene");
  countySelection.options[25] = new Option("Gladwin", "glad");
  countySelection.options[26] = new Option("Gogebic", "goge");
  countySelection.options[27] = new Option("GrandTraverse", "grtr");
  countySelection.options[28] = new Option("Gratiot", "grat");
  countySelection.options[29] = new Option("Hillsdale", "hill");
  countySelection.options[30] = new Option("Houghton", "houg");
  countySelection.options[31] = new Option("Huron", "huro");
  countySelection.options[32] = new Option("Ingham", "ingh");
  countySelection.options[33] = new Option("Ionia", "ioni");
  countySelection.options[34] = new Option("Iosco", "iosc");
  countySelection.options[35] = new Option("Iron", "iron");
  countySelection.options[36] = new Option("Isabella", "isab");
  countySelection.options[37] = new Option("Jackson", "jack");
  countySelection.options[38] = new Option("Kalamazoo", "kzoo");
  countySelection.options[39] = new Option("Kalkaska", "kalk");
  countySelection.options[40] = new Option("Kent", "kent");
  countySelection.options[41] = new Option("Keweenaw", "kewe");
  countySelection.options[42] = new Option("Lake", "lake");
  countySelection.options[43] = new Option("Lapeer", "lape");
  countySelection.options[44] = new Option("Leelanau", "leel");
  countySelection.options[45] = new Option("Lenawee", "lena");
  countySelection.options[46] = new Option("Livingston", "livi");
  countySelection.options[47] = new Option("Luce", "luce");
  countySelection.options[48] = new Option("Mackinac", "mack");
  countySelection.options[49] = new Option("Macomb", "maco");
  countySelection.options[50] = new Option("Manistee", "mani");
  countySelection.options[51] = new Option("Marquette", "marq");
  countySelection.options[52] = new Option("Mason", "maso");
  countySelection.options[53] = new Option("Mecosta", "meco");
  countySelection.options[54] = new Option("Menominee", "meno");
  countySelection.options[55] = new Option("Midland", "midl");
  countySelection.options[56] = new Option("Missaukee", "miss");
  countySelection.options[57] = new Option("Monroe", "monr");
  countySelection.options[58] = new Option("Montcalm", "mclm");
  countySelection.options[59] = new Option("Montmorency", "mtmo");
  countySelection.options[60] = new Option("Muskegon", "musk");
  countySelection.options[61] = new Option("Newaygo", "newa");
  countySelection.options[62] = new Option("Oakland", "oakl");
  countySelection.options[63] = new Option("Oceana", "ocea");
  countySelection.options[64] = new Option("Ogemaw", "ogem");
  countySelection.options[65] = new Option("Ontonagon", "onto");
  countySelection.options[66] = new Option("Osceola", "osce");
  countySelection.options[67] = new Option("Oscoda", "osco");
  countySelection.options[68] = new Option("Otsego", "otse");
  countySelection.options[69] = new Option("Ottawa", "otta");
  countySelection.options[70] = new Option("PresqueIsle", "pres");
  countySelection.options[71] = new Option("Roscommon", "rosc");
  countySelection.options[72] = new Option("Saginaw", "sagi");
  countySelection.options[73] = new Option("Sanilac", "sani");
  countySelection.options[74] = new Option("Schoolcraft", "scho");
  countySelection.options[75] = new Option("Shiawassee", "shia");
  countySelection.options[76] = new Option("St.Clair", "stcl");
  countySelection.options[77] = new Option("St.Joseph", "stjo");
  countySelection.options[78] = new Option("Tuscola", "tusc");
  countySelection.options[79] = new Option("VanBuren", "vanb");
  countySelection.options[80] = new Option("Washtenaw", "wash");
  countySelection.options[81] = new Option("Wayne", "wayn");
  countySelection.options[82] = new Option("Wexford", "wexf");
  addMarker(44.68410000, -83.58100000, "Alcona", "alco");
  addMarker(46.42460000, -86.49030000, "Alger", "alge");
  addMarker(42.59390000, -85.90840000, "Allegan", "alle");
  addMarker(45.03170000, -83.57780000, "Alpena", "alpe");
  addMarker(45.01020000, -85.14500000, "Antrim", "antr");
  addMarker(44.03710000, -83.86590000, "Arenac", "aren");
  addMarker(46.69310000, -88.33550000, "Baraga", "bara");
  addMarker(42.59510000, -85.30850000, "Barry", "barr");
  addMarker(43.73790000, -83.93330000, "Bay", "bay");
  addMarker(44.64590000, -86.03700000, "Benzie", "benz");
  addMarker(42.00150000, -86.52380000, "Berrien", "berr");
  addMarker(41.91630000, -85.05930000, "Branch", "bran");
  addMarker(42.24640000, -85.00450000, "Calhoun", "calh");
  addMarker(41.91530000, -85.99310000, "Cass", "cass");
  addMarker(45.43750000, -85.18130000, "Charlevoix", "char");
  addMarker(45.49330000, -84.46910000, "Cheboygan", "cheb");
  addMarker(46.34270000, -84.35640000, "Chippewa", "chip");
  addMarker(43.98900000, -84.84740000, "Clare", "clar");
  addMarker(42.94420000, -84.60070000, "Clinton", "clin");
  addMarker(44.68300000, -84.61040000, "Crawford", "craw");
  addMarker(45.85470000, -86.91350000, "Delta", "delt");
  addMarker(45.98500000, -87.87600000, "Dickinson", "dick");
  addMarker(42.59610000, -84.83820000, "Eaton", "eato");
  addMarker(45.53000000, -84.92470000, "Emmet", "emme");
  addMarker(43.00200000, -83.69250000, "Genesee", "gene");
  addMarker(43.98770000, -84.38690000, "Gladwin", "glad");
  addMarker(46.43160000, -89.70440000, "Gogebic", "goge");
  addMarker(44.75160000, -85.57510000, "GrandTraverse", "grtr");
  addMarker(43.29190000, -84.60690000, "Gratiot", "grat");
  addMarker(41.88480000, -84.59350000, "Hillsdale", "hill");
  addMarker(46.85300000, -88.60960000, "Houghton", "houg");
  addMarker(43.86910000, -83.03680000, "Huron", "huro");
  addMarker(42.59920000, -84.37200000, "Ingham", "ingh");
  addMarker(42.94490000, -85.07470000, "Ionia", "ioni");
  addMarker(44.33680000, -83.60220000, "Iosco", "iosc");
  addMarker(46.17060000, -88.55400000, "Iron", "iron");
  addMarker(43.64050000, -84.84740000, "Isabella", "isab");
  addMarker(42.24760000, -84.42470000, "Jackson", "jack");
  addMarker(42.24540000, -85.52980000, "Kalamazoo", "kzoo");
  addMarker(44.68490000, -85.09050000, "Kalkaska", "kalk");
  addMarker(43.03140000, -85.55030000, "Kent", "kent");
  addMarker(47.69530000, -88.48280000, "Keweenaw", "kewe");
  addMarker(43.99100000, -85.80230000, "Lake", "lake");
  addMarker(43.10360000, -83.22220000, "Lapeer", "lape");
  addMarker(44.99260000, -85.84170000, "Leelanau", "leel");
  addMarker(41.89460000, -84.06310000, "Lenawee", "lena");
  addMarker(42.60340000, -83.91120000, "Livingston", "livi");
  addMarker(46.50020000, -85.55110000, "Luce", "luce");
  addMarker(45.98370000, -84.98970000, "Mackinac", "mack");
  addMarker(42.67230000, -82.90310000, "Macomb", "maco");
  addMarker(44.34140000, -86.10220000, "Manistee", "mani");
  addMarker(46.44880000, -87.61660000, "Marquette", "marq");
  addMarker(43.99720000, -86.27660000, "Mason", "maso");
  addMarker(43.64090000, -85.32390000, "Mecosta", "meco");
  addMarker(45.54030000, -87.57630000, "Menominee", "meno");
  addMarker(43.64730000, -84.38730000, "Midland", "midl");
  addMarker(44.33690000, -85.09460000, "Missaukee", "miss");
  addMarker(41.90900000, -83.47770000, "Monroe", "monr");
  addMarker(43.29360000, -85.19910000, "Montcalm", "mclm");
  addMarker(45.02840000, -84.12640000, "Montmorency", "mtmo");
  addMarker(43.29500000, -86.12640000, "Muskegon", "musk");
  addMarker(43.55430000, -85.80090000, "Newaygo", "newa");
  addMarker(42.66010000, -83.38630000, "Oakland", "oakl");
  addMarker(43.64330000, -86.28970000, "Oceana", "ocea");
  addMarker(44.33480000, -84.12710000, "Ogemaw", "ogem");
  addMarker(46.68240000, -89.37620000, "Ontonagon", "onto");
  addMarker(43.98930000, -85.32590000, "Osceola", "osce");
  addMarker(44.68190000, -84.12940000, "Oscoda", "osco");
  addMarker(45.02840000, -84.61220000, "Otsego", "otse");
  addMarker(42.98680000, -86.02680000, "Ottawa", "otta");
  addMarker(45.41260000, -83.81690000, "PresqueIsle", "pres");
  addMarker(44.33590000, -84.61110000, "Roscommon", "rosc");
  addMarker(43.34850000, -84.03260000, "Saginaw", "sagi");
  addMarker(43.42230000, -82.81180000, "Sanilac", "sani");
  addMarker(46.13130000, -86.24000000, "Schoolcraft", "scho");
  addMarker(42.95430000, -84.14530000, "Shiawassee", "shia");
  addMarker(42.84360000, -82.70470000, "St.Clair", "stcl");
  addMarker(41.91530000, -85.54200000, "St.Joseph", "stjo");
  addMarker(43.47530000, -83.40170000, "Tuscola", "tusc");
  addMarker(42.24500000, -86.06390000, "VanBuren", "vanb");
  addMarker(42.25350000, -83.83660000, "Washtenaw", "wash");
  addMarker(42.24130000, -83.21100000, "Wayne", "wayn");
  addMarker(44.33870000, -85.57800000, "Wexford", "wexf");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

